<?php

class CTR_BASE extends CHIPTUNINGRESELLER
{

    public  $vehicle_type        = "";
    public  $search_term         = "";
    public  $get_media         = "";
    public  $get_type         = "";
    public  $brand_logo          = "";
    public  $brand_id            = "";
    public  $series_id           = "";
    public  $build_id            = "";
    public  $engine_id           = "";
    public  $brand_slug            = "";
    public  $series_slug           = "";
    public  $build_slug            = "";
    public  $engine_slug           = "";
    public  $hpower              = "";
    public  $power               = "";
    public  $registration_nl     = "";

    public  $vehicle_type_list  = null;
    public  $simp_vehicle_type  = null;
    public  $show_vehicle_type  = true;
    public  $meta_title          = "";
    public  $tagline            = "";
    public  $end_title           = "";

    public function __construct()
    {
        add_action('init', array($this, 'rewrite'), 0);
        add_filter('query_vars', array($this, 'query_vars'), 1);
        add_action('template_include', array($this, 'activate_template'), 20);

        $this->meta_title = __("Chiptuning Specifications", 'chiptuningreseller');
    }

    /**
     * Set the correct titles with Yoast (if active)
     *
     * @return void
     */
    public function set_titles()
    {
        add_filter('document_title_parts', function () {
            return ['tagline' => $this->get_title()];
        }, 10);

        /** YOAST functionalities for adding custom titles and descriptions **/
        add_filter('wpseo_title', function () {
            return $this->get_title();
        }, 10);
        add_filter('wpseo_metadesc', function () {
            return $this->get_title();
        }, 10);
        add_filter('wpseo_opengraph_url', function () {
            return $this->get_url();
        }, 10);
        add_filter('wpseo_opengraph_desc', function () {
            return $this->get_title();
        }, 10);
        add_filter('wpseo_opengraph_image', function () {
            return false;
        }, 10);
        add_filter('wpseo_twitter_description', function () {
            return $this->get_title();
        }, 10);
        add_filter( 'wpseo_canonical', function () {
            $actual_link = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
            return $actual_link;
        }, 10);
    }
  

    /** Rewrite chip-tuning urls to match various data and then redirect to correct function */
    public function rewrite()
    {
        $SETTINGS = $this->get_settings();

        $custom_url = isset($SETTINGS['start_url']) ? $SETTINGS['start_url'] : 'chip-tuning';

        add_rewrite_rule('^'. $custom_url .'$', 'index.php?ctr=1', 'top');
        add_rewrite_rule('^'. $custom_url .'/media/(.*)/(.*)?', 'index.php?ctr=1&get_media=$matches[2]&get_type=$matches[1]', 'top' );
        add_rewrite_rule('^'. $custom_url .'/search/(.*)?', 'index.php?ctr=1&search_term=$matches[1]', 'top' );

		add_rewrite_rule('^'. $custom_url .'/(.*)/(.*)/(.*)/(.*)/(.*)/(.*)?$', 
			'index.php?ctr=1&vehicle_type=$matches[1]&brand_slug=$matches[2]&serie_slug=$matches[3]&build_slug=$matches[4]&engine_slug=$matches[5]&engine_id=$matches[6]', 'top' );
		add_rewrite_rule('^'. $custom_url .'/(.*)/(.*)/(.*)/(.*)/(.*)?$', 
			'index.php?ctr=1&vehicle_type=$matches[1]&brand_slug=$matches[2]&serie_slug=$matches[3]&build_slug=$matches[4]&engine_slug=$matches[5]', 'top' );
		add_rewrite_rule('^'. $custom_url .'/(.*)/(.*)/(.*)/(.*)?$', 
			'index.php?ctr=1&vehicle_type=$matches[1]&brand_slug=$matches[2]&serie_slug=$matches[3]&build_slug=$matches[4]', 'top' );
		add_rewrite_rule('^'. $custom_url .'/(.*)/(.*)/(.*)?$', 
			'index.php?ctr=1&vehicle_type=$matches[1]&brand_slug=$matches[2]&serie_slug=$matches[3]', 'top' );
		add_rewrite_rule('^'. $custom_url .'/(.*)/(.*)/?$', 
			'index.php?ctr=1&vehicle_type=$matches[1]&brand_slug=$matches[2]', 'top' );
        add_rewrite_rule('^'. $custom_url .'/(.*)/?', 'index.php?ctr=1&vehicle_type=$matches[1]', 'top' );
    }

    public function setParams($params = [])
    {
        $this->vehicle_type     = isset($params['vehicle_type']) ? $params['vehicle_type'] : '';
        $this->search_term       = $params['search_term'];
        $this->get_media       = $params['get_media'];
        $this->get_type       = $params['get_type'];
        $this->brand_id         = $params['brand_id'];
        $this->series_id        = $params['series_id'];
        $this->build_id         = $params['build_id'];
        $this->engine_id        = $params['engine_id'];
        $this->brand_slug         = $params['brand_slug'];
        $this->series_slug        = $params['series_slug'];
        $this->build_slug         = $params['build_slug'];
        $this->engine_slug        = $params['engine_slug'];
        $this->image            = $params['image'];
        $this->type             = $params['type'];
        $this->hpower           = $params['hpower'];
        $this->power            = $params['power'];
        $this->ajax             = $params['ajax'];
        $this->debug            = $params['debug'];
        $this->registration_nl            = $params['registration_nl'];
    }

    public function query_vars($vars)
    {
        $vars[] = 'ctr';
        $vars[] = 'vehicle_type';
        $vars[] = 'search_term';
        $vars[] = 'get_media';
        $vars[] = 'get_type';
        $vars[] = 'brand_id';
        $vars[] = 'serie_id';
        $vars[] = 'build_id';
        $vars[] = 'engine_id';
        $vars[] = 'hpower';
        $vars[] = 'power';
        $vars[] = 'ajax';
        $vars[] = 'brand_slug';
        $vars[] = 'serie_slug';
        $vars[] = 'build_slug';
        $vars[] = 'engine_slug';
        $vars[] = 'image_id';
        $vars[] = 'image_type';
        $vars[] = 'registration_nl';
        return $vars;
    }

    public function get_query_vars()
    {
        global $wp;
        $vehicle_type       = (get_query_var('vehicle_type') != '') ? strip_tags(get_query_var('vehicle_type')) : null;
        $brand_id           = (get_query_var('brand_id') != '') ? strip_tags(get_query_var('brand_id')) : null;
        $search_term        = (get_query_var('search_term') != '') ? strip_tags(get_query_var('search_term')) : null;
        $get_media          = (get_query_var('get_media') != '') ? strip_tags(get_query_var('get_media')) : null;
        $get_type           = (get_query_var('get_type') != '') ? strip_tags(get_query_var('get_type')) : null;
        $model_id           = (get_query_var('model_id') != '') ? strip_tags(get_query_var('model_id')) : null;
        $serie_id           = (get_query_var('serie_id') != '') ? strip_tags(get_query_var('serie_id')) : null;
        $build_id           = (get_query_var('build_id') != '') ? strip_tags(get_query_var('build_id')) : null;
        $engine_id          = (get_query_var('engine_id') != '' and get_query_var('engine_id') != '-') ? strip_tags(get_query_var('engine_id')) : null;
        $brand_slug         = (get_query_var('brand_slug') != '') ? strip_tags(get_query_var('brand_slug')) : null;
        $serie_slug         = (get_query_var('serie_slug') != '') ? strip_tags(get_query_var('serie_slug')) : null;
        $build_slug         = (get_query_var('build_slug') != '') ? strip_tags(get_query_var('build_slug')) : null;
        $engine_slug        = (get_query_var('engine_slug') != '' and get_query_var('engine_slug') != '-') ? strip_tags(get_query_var('engine_slug')) : null;
        $image_type         = (get_query_var('image_type') != '') ? strip_tags(get_query_var('image_type')) : null;
        $image_id           = (get_query_var('image_id') != '') ? strip_tags(get_query_var('image_id')) : null;
        $ajax               = (get_query_var('ajax') != '') ? true : false;
        $registration_nl    = (get_query_var('registration_nl') != '') ? strip_tags(get_query_var('registration_nl')) : false;

        $params['vehicle_type']         = $vehicle_type;
        $params['search_term']          = $search_term;
        $params['get_media']            = $get_media;
        $params['get_type']             = $get_type;
        $params['brand_id']             = $brand_id;
        $params['serie_id']             = $serie_id;
        $params['model_id']             = $model_id;
        $params['build_id']             = $build_id;
        $params['engine_id']            = $engine_id;
        $params['brand_slug']           = $brand_slug;
        $params['serie_slug']           = $serie_slug;
        $params['build_slug']           = $build_slug;
        $params['engine_slug']          = $engine_slug;
        $params['image_id']             = $image_id;
        $params['image_type']           = $image_type;
        $params['ajax']                 = $ajax;
        $params['registration_nl']      = $registration_nl;
        return $params;
    }

    /**
     * Override the default template if our main template exists
     *
     * @param [type] $template
     * @return void
     */
    public function activate_template($template)
    {
        if (get_query_var('ctr', false) !== false) {
            $mainTemplate = plugin_dir_path(__FILE__) . 'views/front/main.php';
            if (file_exists($mainTemplate)) {
                if(get_query_var('ajax', false) !== false) {
                    
                    include($mainTemplate);
                    exit;
                } else {
                    return $mainTemplate;
                }
            }            
        }
        //Fall back to original template
        return $template;
    }


/**
 *
 * Create custom headers for our specifications pages
 * Global wordpress home_url function used for current URL
 *
 ***/
public function create_headers()
{
    /** If the Yoast SEO plugin is activated, don't do anything **/
    if (class_exists('WPSEO_Rewrite')) {
        return null;
    }

    $current_url = $this->get_url();
    $headers = function () use ($current_url) {
        ?>
            <meta property="og:title" content="<?php echo $this->meta_title; ?> <?php echo $this->tagline; ?>" />
            <meta property="og:site_name" content="<?php bloginfo('name') ?>" />
            <meta property="og:url" content="<?php echo $current_url ?>" />
            <meta property="og:description" content="<?php bloginfo('name') ?> - <?php echo $this->meta_title; ?> <?php echo $this->tagline; ?>" />
            <meta property="og:type" content="article" />
        <?php
    };

    add_action('wp_head', $headers);
}

/**
 * Add Style and Javascript where needed
 */
public function add_assets()
{
    wp_register_style( 'ctr-bootstrap', plugins_url('ctr/assets/css/bootstrap.min.css', dirname(__FILE__)) );
    wp_enqueue_style( 'ctr-bootstrap' );

    wp_register_style( 'ctr', plugins_url('ctr/assets/css/chiptuningreseller.css', dirname(__FILE__)) );
    wp_enqueue_style( 'ctr' );
}


/** Get the URL of the current request **/
public function get_url()
{
    global $wp;
    $current_url = home_url(add_query_arg(array(), $wp->request));
    return $current_url;
}

public function get_media_dir()
{
    $uploadDir =  wp_upload_dir();
    $fileDir = $uploadDir['basedir'] . '/ctr/media/';
    return $fileDir;
}

public function set_title($tagline)
{
    $this->tagline = $tagline;
}

public function get_title()
{
    return get_bloginfo('name') . ' - ' . __("Specifications for", "ctr") . ' ' . $this->tagline;
}

/*** Get the custom Stage texts ***/
public function get_stage_text()
{
    if (isset($this->get_settings()['stage_text'])) {
        return stripslashes($this->get_settings()['stage_text']);
    }
}

/** Find a key in an array, recursively **/
public function recursiveFind(array $haystack, $needle)
{
    $iterator  = new RecursiveArrayIterator($haystack);
    $recursive = new RecursiveIteratorIterator(
        $iterator,
        RecursiveIteratorIterator::SELF_FIRST
    );
    foreach ($recursive as $key => $value) {
        if ($key === $needle) {
            yield $value;
        }
    }
}
}
?>