<?php

/**
 * Fired during plugin activation
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.0.0
 *
 * @package    Ctr
 * @subpackage Ctr/includes
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-media.php';

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */

class Ctr_Activator {
	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    3.0.0
	 */
	public static function activate() {
		$success = self::create_table();
        $success = self::fill_table();

        // Copy the needed assets
        $media = new CTR_Media();
        $media->copy_assets();

		return $success;
	}

	/** Create the table used for storing our data */
	public static function create_table() {
		global $wpdb;
		/** CREATION TABLE ChiptuningReseller */
        $wpdb->query("CREATE TABLE IF NOT EXISTS {$wpdb->prefix}chiptuningreseller 
			(id INT  AUTO_INCREMENT PRIMARY KEY ,
			company_name VARCHAR(255) DEFAULT NULL,
			start_url TEXT DEFAULT NULL,
			api_key TEXT DEFAULT NULL,
			mailto VARCHAR(255) DEFAULT '',
			enable_cache TINYINT(1) DEFAULT 1,
			stage_text TEXT DEFAULT NULL,
			display_lang VARCHAR(255) DEFAULT NULL,
			include_css TINYINT(1) DEFAULT 0,
			custom_css MEDIUMTEXT DEFAULT '',
			show_price TINYINT DEFAULT '0',
			currency VARCHAR(10) DEFAULT '€',
			show_data TEXT DEFAULT NULL,
			fixed_stage_prices TEXT DEFAULT NULL,
			layout_settings TEXT DEFAULT NULL,
			seo_settings TEXT DEFAULT NULL,
			reg_search VARCHAR(255) DEFAULT NULL,
			_time_creation DATETIME DEFAULT NULL);");
	}

	/** Fill the table with initial data (if not present yet) */
	public static function fill_table() {
		global $wpdb;

		$result = $wpdb->query("SELECT id FROM {$wpdb->prefix}chiptuningreseller WHERE id = 1");
        if($result !== 1) {
        /** Insert default line */
        $query = $wpdb->query("INSERT INTO {$wpdb->prefix}chiptuningreseller (id, company_name, start_url, api_key, enable_cache, display_lang, include_css, show_price, show_data, layout_settings, _time_creation) 
            VALUES (1, 'ChiptuningReseller', 'chip-tuning', '', 1, 'auto', 1, 0, '{\"stages\": [{\"stage_1\":\"1\",\"stage_2\":\"1\",\"stage_3\":\"1\",\"stage_4\":\"1\",\"stage_dsg\":\"1\",\"stage_extra\":\"1\"}]',
            '{\"show_graph\":\"1\",\"show_dyno\":\"1\",\"show_basic_table\":\"1\", \"show_selector\":\"none\",\"graph_colors\":{\"hp\":\"rgba(221,51,51,1)\",\"nm\":\"rgba(30,115,190,1)\"}}', '".date('d-m-Y H:i:s')."')");
        }
		return $query;  
    }
}