<?php
/**
 * Vehicle Types Class
 *
 * This class communicates with the CTR database
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Brands {

    private $helper;
    private $use_cache;
    private $database;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct() {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        $this->use_cache = $this->database->getSettings()['enable_cache'];

    }
    

    public function getBrands($typeSlug = 'cars', $brandId = null) {
        if (isset($typeSlug)) {
            // Translate the typeslug to our internal naming
            $typeSlug = $this->helper->translate_vehicle_type($typeSlug, 'internal');
            $cached = $this->helper->get_cache('brands_' . $typeSlug);
            if(($this->use_cache == 1) && (is_array($cached))) {
                return $cached;
            }

            global $wpdb;
            $catalogData = null;
            $url = API_URL . 'brands?vehicle_type=' . $typeSlug;
            
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );

            if (is_wp_error( $response )) {
               $error_message = $response->get_error_message();
               //echo "Something went wrong: $error_message";
            } else {
                $responseData = json_decode($response['body'], true);
                if(isset($brandId)) {
                    foreach($responseData as $brand) {
                        if($brand['id'] == $brandId) {
                            return $brand;
                        };
                    }
                }
                $this->helper->set_cache('brands_' . $typeSlug, $responseData, 'ctr', 43300); // Save our brands for at least 12 hours
                return $responseData;
            }
        }
    }

    public function getTypes($id) {

    }

}