<?php
/**
 * Vehicle Engines Class
 *
 * This class communicates with the CTR database and retrieves the SERIES
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Engines {

    private $helper;
    private $vehicle_type;
    private $use_cache;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($vehicle_type = 'cars') {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        $this->use_cache = $this->database->getSettings()['enable_cache'];
        $this->vehicle_type = $this->helper->translate_vehicle_type($vehicle_type, 'internal');
    }
    

    /***
    *
    * Get a list with vehicle engines
    *
    ***/
    public function getEngines($buildId = NULL, $brandSlug = NULL, $serieSlug = NULL, $buildSlug = NULL, $searchTerm = NULL) {
        if (isset($buildId) || (isset($buildSlug)) && isset($brandSlug) && isset($serieSlug)) {
            $cacheCode = $this->vehicle_type . '_engines_' . base64_encode('_'. $brandSlug . '_' . $buildSlug . '' . $buildId);
            $engineCache = $this->helper->get_cache($cacheCode);
            if(false !== $engineCache && $this->use_cache == 1 && !empty($engineCache)) {
                return $engineCache;
            }

            global $wpdb;
            $catalogData = null;
            $catalogData = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
            $url = (isset($buildSlug)) ? API_SEARCH_URL . '?type='. $this->vehicle_type .'&brand_slug='. $brandSlug .'&serie_slug='. $serieSlug .'&build_slug=' . $buildSlug : API_URL . 'engines?build_id=' . $buildId;
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );
            
            if (is_wp_error( $response )) {
               $error_message = $response->get_error_message();
               echo "Something went wrong: $error_message";
            } else {
               $responseData = json_decode($response['body'], true);
               $this->helper->set_cache($cacheCode, $responseData, 'ctr', 7200); // Save our builds for at least 2 hours
               return $responseData;
            }
        }
    }

}