<?php

/**
 * Database activities
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.0.0
 *
 * @package    Ctr
 * @subpackage Ctr/includes
 */

/**
 * Database activities
 *
 * This class communicates with the CTR database
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 * @update 4.0.1.3 - use wp_cache for minimizing the db load
 */

require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-activator.php';

class Ctr_DB {
	private $settings;

	/**
	 * Get CTR database Settings
	 * 
	 */
	public function getSettings() {
		
		if(wp_cache_get(get_current_blog_id() . '_ctr_settings', 'chiptuningreseller')) {
			return wp_cache_get(get_current_blog_id() . '_ctr_settings', 'chiptuningreseller');
		}
		
		global $wpdb;
        $data = null;
        $table_name = $wpdb->prefix.'chiptuningreseller';
		
        // if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
		// 	$helper = new Ctr_Helpers();
		// 	$helper->show_notice("error", __("Database failure", "ctr") . '<br/>Warning! The CTR database could not be located. To enable it, please disable and enable the plugin again.', "ctr");
        //     return null;
        // }
        
        $data = $wpdb->get_row("SELECT enable_cache, start_url, mailto, stage_text, display_lang, include_css, custom_css, show_price, currency, show_data, fixed_stage_prices, layout_settings, seo_settings, reg_search FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);
        $displayData = isset($data['show_data']) ? json_decode($data['show_data'], true) : '';
        $data['seo_settings'] = isset($data['seo_settings']) ? json_decode($data['seo_settings'], true) : '';
        $data['layout_settings'] = isset($data['layout_settings']) ? json_decode($data['layout_settings'], true) : '';
        $data['fixed_stage_prices'] = isset($data['fixed_stage_prices']) ? json_decode($data['fixed_stage_prices'], true) : '';
        $data['show_stages'] = isset($displayData['stages']) ? json_decode($displayData['stages'], true) : '';
        $data['show_vehicles'] = isset($displayData['vehicles']) ? json_decode($displayData['vehicles'], true) : '';
		$data['reg_search'] = isset($data['reg_search']) ? json_decode($data['reg_search'], true) : '';
		
		$this->settings = $data;
		wp_cache_set(get_current_blog_id() . '_ctr_settings', $data, 'chiptuningreseller', 3600);
		return $data;
	}

	public static function saveSettings($postData) {
		global $wpdb;

		/**
		 * Check which type of form we want to save
		 */
		if(isset($postData['form_type'])) {
			/**
			 * The main form
			 */
			if($postData['form_type'] == 'main') {
				
				$data['currency'] = strlen($postData['currency']) > 0 ? $postData['currency'] : '€';

				$data['show_price'] = isset($postData['show_price']) ?? 0;
				
				$data['enable_cache'] = isset($postData['enable_cache']) ?? 0;
				
				if(isset($postData['start_url'])) {
					$data['start_url'] = $postData['start_url'];
				}

				if(!empty($postData['mailto'])) {
					$data['mailto'] = $postData['mailto'];
				}

				if(isset($postData['display_lang'])) {
					$data['display_lang'] = $postData['display_lang'];
				}

				if(isset($postData['show_stages'])) {
					$data['show_data']['stages'] = json_encode($postData['show_stages']);
				}
		
				if(isset($postData['show_vehicles']) && !empty($postData['show_stages'])) {
					$data['show_data']['vehicles'] = json_encode($postData['show_vehicles']);
				}

				if(isset($postData['api_key'])) {
					$data['api_key'] = $postData['api_key'];
				}
			} 
			/** Customisation form */
			elseif($postData['form_type'] == 'customisation') {
				if(!empty($postData['reg_search'])) {
					$data['reg_search'] = json_encode($postData['reg_search']);
				}

				if(isset($postData['include_css'])) {
					$data['include_css'] = !empty($postData['include_css']) ? 1 : 0;
				}

				if(!empty($postData['layout_settings'])) {
					$data['layout_settings'] = json_encode($postData['layout_settings']);
				}

				if(!empty($postData['stage_text'])) {
					$data['stage_text'] = $postData['stage_text'];
				}
		
				if(!empty($postData['custom_css'])) {
					$data['custom_css'] = $postData['custom_css'];
				}
			} elseif($postData['form_type'] == 'prices') {
				if(!empty($postData['fixed_stage_prices'])) {
					$data['fixed_stage_prices'] = json_encode($postData['fixed_stage_prices']);
				}
			} elseif($postData['form_type'] == 'seo') {
				if(!empty($postData['seo_settings'])) {
					$data['seo_settings'] = json_encode($postData['seo_settings']);
				}
			}
			if(isset($data['show_data'])) {
				$data['show_data'] = json_encode($data['show_data']);
			}
		}
		// Check if the settings record exists
		$count = $wpdb->get_var("SELECT COUNT(*) FROM {$wpdb->prefix}chiptuningreseller WHERE id = 1");
		
		wp_cache_delete(get_current_blog_id() . '_ctr_settings', 'chiptuningreseller');
		if($count == 1) {
			// If it exists, update, otherwise create and save
			return $wpdb->update("{$wpdb->prefix}chiptuningreseller", $data, array('id'=> '1'));
		} else {
			
			$ctr_activator = new Ctr_Activator();
			if($ctr_activator->activate()) {
				return $wpdb->update("{$wpdb->prefix}chiptuningreseller", $data, array('id'=> '1'));
			} else {
				echo '<div class="notice notice-error is-dismissible"><h4>WARNING: CTR COULD NOT CREATE THE INITIAL TABLE AND CANNOT BE USED.<br/> ARE YOU USING MULTISITE (THIS SHOULD WORK, BUT IN SOME SPECIAL CASES IT CAN CAUSE ISSUES)?<br/>PLEASE ASK YOU ACCOUNTMANAGER FOR HELP!</h4><br/>Please provide these details:<br/>DBName: '.$wpdb->prefix.'<br/>Function: Activator::fill_table</div>';
				return false;
			}
		}
		
	}

	/**
	 * Get the API key
	 */
	public function getApiKey() {
		if(wp_cache_get('ctr_api_key', 'chiptuningreseller')) {
			return wp_cache_get('ctr_api_key', 'chiptuningreseller');
		}

		global $wpdb;
		$data = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1", ARRAY_A);

		if(null != $data) {
			wp_cache_set('ctr_api_key', $data['api_key'], 'chiptuningreseller', 3600);
			return $data['api_key'];
		} else {
			return false;
		}
	}


}
