<?php

	/**
	 * All Rewrite Functionalities
	 *
	 * @link       https://www.chiptuningreseller.com
	 * @since      3.0.0
	 *
	 * @package    Ctr
	 * @subpackage Ctr/includes
	 *
	 * @since      3.0.0
	 * @package    Ctr
	 * @subpackage Ctr/includes
	 * @author     M Bos <support@chiptuningreseller.com>
	 */
	
	require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';
	
	class CTR_Rewrite {
	
		public function __construct($settings = null) {
			add_action('init', array($this, 'rewrite_urls'), 0);
			$ctrDb = new Ctr_DB();
			$this->settings = $ctrSettings ?? $ctrDb->getSettings();
		}
	
		public function rewrite_urls() {
			$custom_url = isset($this->settings['start_url']) ? $this->settings['start_url'] : 'chip-tuning';
			add_rewrite_rule('^' . $custom_url . '/media/(.*)/(.*)/(.*)/([^/]*)', 'index.php?ctr_active=true&ajax=true&ctr_get_media=true&ctr_vehicle_type=$matches[1]&ctr_media_type=$matches[2]&ctr_media_id=$matches[3]&ctr_media_size=$matches[4]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/(.*)/(.*)/(.*)/(.*)/(.*)/(.*)/quote/(.*)/?', 'index.php?ctr_active=true&ctr_vehicle_type=$matches[1]&ctr_brand_slug=$matches[2]&ctr_serie_slug=$matches[3]&ctr_model_slug=$matches[4]&ctr_engine_slug=$matches[5]&ctr_engine_id=$matches[6]&ctr_get_quote=$matches[7]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/(.*)/(.*)/(.*)/(.*)/(.*)/(.*)/?', 'index.php?ctr_active=true&ctr_vehicle_type=$matches[1]&ctr_brand_slug=$matches[2]&ctr_serie_slug=$matches[3]&ctr_model_slug=$matches[4]&ctr_engine_slug=$matches[5]&ctr_engine_id=$matches[6]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/(.*)/(.*)/(.*)/(.*)/(.*)/?', 'index.php?ctr_active=true&ctr_vehicle_type=$matches[1]&ctr_brand_slug=$matches[2]&ctr_serie_slug=$matches[3]&ctr_model_slug=$matches[4]&ctr_engine_slug=$matches[5]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/(.*)/(.*)/(.*)/(.*)/?', 'index.php?ctr_active=true&ctr_vehicle_type=$matches[1]&ctr_brand_slug=$matches[2]&ctr_serie_slug=$matches[3]&ctr_model_slug=$matches[4]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/(.*)/(.*)/(.*)/?', 'index.php?ctr_active=true&ctr_vehicle_type=$matches[1]&ctr_brand_slug=$matches[2]&ctr_serie_slug=$matches[3]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/(.*)/(.*)/?', 'index.php?ctr_active=true&ctr_vehicle_type=$matches[1]&ctr_brand_slug=$matches[2]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/(.*)/?', 'index.php?ctr_active=true&ctr_vehicle_type=$matches[1]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/?', 'index.php?ctr_active=true&ctr_search_term=$matches[1]', 'top' );
			add_rewrite_rule('^' . $custom_url . '/?', 'index.php?ctr_active=true', 'top' );
		}

		/**
		 * Set the custom query vars we can use later on
		 */
		public function set_custom_query_vars($vars) {
			$vars[] = 'ctr_active';
			$vars[] = 'ctr_search_term';
			$vars[] = 'ctr_vehicle_type';
			$vars[] = 'ctr_brand_slug';
			$vars[] = 'ctr_serie_slug';
			$vars[] = 'ctr_model_slug';
			$vars[] = 'ctr_engine_slug';
			$vars[] = 'ctr_engine_id';
			$vars[] = 'ctr_brand_id';
			$vars[] = 'ctr_serie_id';
			$vars[] = 'ctr_build_id';
			$vars[] = 'ctr_get_quote';
			$vars[] = 'ajax';

			/** Media system */
			$vars[] = 'ctr_get_media';
			$vars[] = 'ctr_media_type';
			$vars[] = 'ctr_media_id';
			$vars[] = 'ctr_media_size';
			return $vars;
		}
	
		/** 
		 * Get all relevant query vars and return it in an array 
		 * */
		public function get_query_vars() {
			$data['ctr_active'] 		= get_query_var('ctr_active') != '' ? strip_tags(get_query_var('ctr_active')) : null;
			$data['ctr_search_term'] 	= get_query_var('ctr_search_term') != '' ? strip_tags(get_query_var('ctr_search_term')) : null;
			$data['vehicle_type'] 		= get_query_var('ctr_vehicle_type') != '' ? urldecode(strip_tags(get_query_var('ctr_vehicle_type', null))) : null;
			$data['vehicle_brand'] 		= get_query_var('ctr_brand_slug') != '' ? strip_tags(get_query_var('ctr_brand_slug', null)) : null;
			$data['vehicle_serie'] 		= get_query_var('ctr_serie_slug') != '' ? strip_tags(get_query_var('ctr_serie_slug', null)) : null;
			$data['vehicle_model'] 		= get_query_var('ctr_model_slug') != '' ? strip_tags(get_query_var('ctr_model_slug', null)) : null;
			$data['vehicle_engine'] 	= get_query_var('ctr_engine_slug') != '' ? strip_tags(get_query_var('ctr_engine_slug', null)) : null;
			$data['vehicle_engine_id'] 	= get_query_var('ctr_engine_id') != '' ? strip_tags(get_query_var('ctr_engine_id', null)) : null;
			$data['vehicle_brand_id'] 	= get_query_var('ctr_brand_id') != '' ? strip_tags(get_query_var('ctr_brand_id', null)) : null;
			$data['vehicle_serie_id'] 	= get_query_var('ctr_serie_id') != '' ? strip_tags(get_query_var('ctr_serie_id', null)) : null;
			$data['vehicle_build_id'] 	= get_query_var('ctr_build_id') != '' ? strip_tags(get_query_var('ctr_build_id', null)) : null;
			$data['get_quote'] 			= get_query_var('ctr_get_quote') != '' ? strip_tags(get_query_var('ctr_get_quote', null)) : null;
			$data['is_ajax'] 			= get_query_var('ajax') != '' ? strip_tags(get_query_var('ajax', null)) : null;

			/** Media system */
			$data['ctr_get_media']		= get_query_var('ctr_get_media') != '' ? strip_tags(get_query_var('ctr_get_media', null)) : null;
			$data['ctr_media_type']		= get_query_var('ctr_media_type') != '' ? strip_tags(get_query_var('ctr_media_type', null)) : null;
			$data['ctr_media_id']		= get_query_var('ctr_media_id') != '' ? strip_tags(get_query_var('ctr_media_id', null)) : null;
			$data['ctr_media_size']		= get_query_var('ctr_media_size') != '' ? strip_tags(get_query_var('ctr_media_size', null)) : null;
			
			return $data;
		}
	
	}