<?php

/**
 * AJAX functionalities
 *
 * This class only handles the AJAX Requests for the dropdown Selector
 *
 * @since      4.0.1.5
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-db.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-rewrite.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-templator.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-vehicle-types.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-brands.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-series.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-builds.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-engines.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-stages.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-api-search.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'public/includes/class-ctr-stagedata.php';

class Ctr_Ajax
{
	private $helpers;
	private $settings;

	public function __construct()
	{
        $ajaxRequest = get_query_var( 'ajax' );
        
		$this->helpers = new Ctr_Helpers();
		$this->rewrite_class = new CTR_Rewrite();
		$this->base_dir = wp_upload_dir()['basedir'] . '/ctr/';

		$CtrDB = new Ctr_DB();
		$this->settings = $CtrDB->getSettings();
        $this->handleAjax();
	}

    public function handleAjax()
	{
		$data = $this->rewrite_class->get_query_vars();
		if (isset($data['vehicle_engine_id'])) {
			$apiStages = new Ctr_Stages($data['vehicle_type']);
			$stageData = $apiStages->getStages($data['vehicle_engine_id']);
			if (isset($stageData) && (is_array($stageData))) {
				$vehicle_type = $this->helpers->translate_vehicle_type($stageData['vehicle']['brand']['type']);
				$ROOT_URL = rtrim(get_home_url(), '/') . '/' . $this->settings['start_url'];

				$stageData['url'] = $ROOT_URL . '/' . $vehicle_type . '/' . $stageData['vehicle']['brand']['slug'] . '/' . $stageData['vehicle']['serie']['slug'] . '/' . $stageData['vehicle']['build']['slug'] . '/' . $stageData['engine']['slug'] . '/' . $stageData['engine']['id'];
			}
			wp_send_json($stageData);
			exit;
		}
		if (isset($data['vehicle_build_id'])) {
			$apiEngines = new Ctr_Engines($data['vehicle_build_id']);
			$engineData = $apiEngines->getEngines($data['vehicle_build_id']);
			wp_send_json($engineData);
			exit;
		}
		if (isset($data['vehicle_serie_id'])) {
			$apiBuilds = new Ctr_Builds($data['vehicle_type']);
			$buildData = $apiBuilds->getBuilds($data['vehicle_serie_id']);
			wp_send_json($buildData);
			exit;
		} elseif (isset($data['vehicle_brand_id'])) {
			$apiSeries = new Ctr_Series($data['vehicle_type']);
			$serieData = $apiSeries->getSeries($data['vehicle_brand_id']);
			wp_send_json($serieData);
			exit;
		} elseif (isset($data['vehicle_type'])) {
			$apiBrands = new Ctr_Brands();
			$data['brands'] = $apiBrands->getBrands($data['vehicle_type']);
			wp_send_json($data['brands']);
			exit;
		} else {
			$apiVehicleTypes = new Ctr_VehicleTypes();
			$data['vehicle_types'] = $apiVehicleTypes->getAllTypes();
			wp_send_json($data['vehicle_types']);
			exit;
		}
	}
}

$ajaxHandler = new Ctr_Ajax();